@@ -23,7 +23,7 @@ def start_gui(*args, **kwargs):
     sg.set_options(
         message_box_line_width=80,
         debug_win_size=(100, 30),
-        icon = "cleverdict.ico",
+        icon = "cleverutils.ico",
         font = "calibri 12",
     )
 
