@@ -12,10 +12,10 @@ import pyperclip
 import inspect
 import json
 import keyring
-from clevergui import start_gui, button_menu, text_input, sg_options
-from cleverutils import to_json, timer
-import login_to
-import collect
+from .clevergui import start_gui, button_menu, text_input, sg_options
+from .cleverutils import to_json, timer
+import .login_to
+import .collect
 
 class CleverSession(CleverDict):
     """
